==> jc-1.4.0.tar.gz: javax/security/cert/Certificate.h <==
// public abstract class javax.security.cert.Certificate

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cd3db99c9d425d1c javax_security_cert_Certificate

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_cert_Certificate_H_
#define _JC_javax_security_cert_Certificate_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PublicKey$object;

// Typedefs
typedef struct _jc_javax_security_cert_Certificate$sub_refs	_jc_javax_security_cert_Certificate$sub_refs;
typedef struct _jc_javax_security_cert_Certificate$sub_nonrefs	_jc_javax_security_cert_Certificate$sub_nonrefs;
typedef struct _jc_javax_security_cert_Certificate$refs	_jc_javax_security_cert_Certificate$refs;
typedef struct _jc_javax_security_cert_Certificate$nonrefs	_jc_javax_security_cert_Certificate$nonrefs;
typedef struct _jc_javax_security_cert_Certificate$object	_jc_javax_security_cert_Certificate$object;

typedef const struct _jc_javax_security_cert_Certificate$vmethods	_jc_javax_security_cert_Certificate$vmethods;
typedef const struct _jc_javax_security_cert_Certificate$vtable	_jc_javax_security_cert_Certificate$vtable;
typedef const struct _jc_javax_security_cert_Certificate$vtype	_jc_javax_security_cert_Certificate$vtype;

// Constructors
extern void _jc_javax_security_cert_Certificate$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_cert_Certificate$object *);

// Virtual methods
extern jboolean _jc_javax_security_cert_Certificate$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_java_lang_Object$object *);
extern _jc_byte_array *_jc_javax_security_cert_Certificate$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_javax_security_cert_Certificate$object *);
extern struct _jc_object *_jc_javax_security_cert_Certificate$method$getPublicKey$11feb83e68327d4d(_jc_env *, struct _jc_javax_security_cert_Certificate$object *);
extern jint _jc_javax_security_cert_Certificate$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_security_cert_Certificate$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_cert_Certificate$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_security_cert_Certificate$object *);
extern void _jc_javax_security_cert_Certificate$method$verify$65bf2aeb739ee695(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_object *);
extern void _jc_javax_security_cert_Certificate$method$verify$c65b5b574afcbb17(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_cert_Certificate$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$getPublicKey$11feb83e68327d4d;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$verify$65bf2aeb739ee695;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$verify$c65b5b574afcbb17;

// Virtual methods structure
struct _jc_javax_security_cert_Certificate$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_java_lang_Object$object *);
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *);
	struct _jc_object	*(*getPublicKey$11feb83e68327d4d)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *);
	void	(*verify$65bf2aeb739ee695)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_object *);
	void	(*verify$c65b5b574afcbb17)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_javax_security_cert_Certificate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_cert_Certificate$vmethods	javax_security_cert_Certificate;
};

// Vtype
struct _jc_javax_security_cert_Certificate$vtype {
	_jc_type			type;
	_jc_javax_security_cert_Certificate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_cert_Certificate$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_cert_Certificate$refs {
    _jc_javax_security_cert_Certificate$sub_refs	javax_security_cert_Certificate;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_cert_Certificate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_cert_Certificate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_cert_Certificate$sub_nonrefs	javax_security_cert_Certificate;
};

// Object instance structure
struct _jc_javax_security_cert_Certificate$object {
	_jc_javax_security_cert_Certificate$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_cert_Certificate$vtype	*vtype;
	_jc_javax_security_cert_Certificate$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_cert_Certificate$vtype _jc_javax_security_cert_Certificate$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_cert_Certificate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_cert_Certificate$class_object;

#endif	/* _JC_javax_security_cert_Certificate_H_ */

==> jc-1.4.6.tar.gz: javax/security/cert/Certificate.h <==
// public abstract class javax.security.cert.Certificate

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cd3db99c9d425d1c javax_security_cert_Certificate

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_cert_Certificate_H_
#define _JC_javax_security_cert_Certificate_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PublicKey$object;

// Typedefs
typedef struct _jc_javax_security_cert_Certificate$sub_refs	_jc_javax_security_cert_Certificate$sub_refs;
typedef struct _jc_javax_security_cert_Certificate$sub_nonrefs	_jc_javax_security_cert_Certificate$sub_nonrefs;
typedef struct _jc_javax_security_cert_Certificate$refs	_jc_javax_security_cert_Certificate$refs;
typedef struct _jc_javax_security_cert_Certificate$nonrefs	_jc_javax_security_cert_Certificate$nonrefs;
typedef struct _jc_javax_security_cert_Certificate$object	_jc_javax_security_cert_Certificate$object;

typedef const struct _jc_javax_security_cert_Certificate$vmethods	_jc_javax_security_cert_Certificate$vmethods;
typedef const struct _jc_javax_security_cert_Certificate$vtable	_jc_javax_security_cert_Certificate$vtable;
typedef const struct _jc_javax_security_cert_Certificate$vtype	_jc_javax_security_cert_Certificate$vtype;

// Constructors
extern void _jc_javax_security_cert_Certificate$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_cert_Certificate$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_security_cert_Certificate$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_javax_security_cert_Certificate$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_javax_security_cert_Certificate$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_security_cert_Certificate$method$getPublicKey$11feb83e68327d4d(_jc_env *, struct _jc_javax_security_cert_Certificate$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_security_cert_Certificate$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_security_cert_Certificate$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_cert_Certificate$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_security_cert_Certificate$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_cert_Certificate$method$verify$65bf2aeb739ee695(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_cert_Certificate$method$verify$c65b5b574afcbb17(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_cert_Certificate$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$getPublicKey$11feb83e68327d4d;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$verify$65bf2aeb739ee695;
extern _jc_method _jc_javax_security_cert_Certificate$method_info$verify$c65b5b574afcbb17;

// Virtual methods structure
struct _jc_javax_security_cert_Certificate$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPublicKey$11feb83e68327d4d)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *) _JC_JCNI_ATTR;
	void	(*verify$65bf2aeb739ee695)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*verify$c65b5b574afcbb17)(_jc_env *, struct _jc_javax_security_cert_Certificate$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_cert_Certificate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_cert_Certificate$vmethods	javax_security_cert_Certificate;
};

// Vtype
struct _jc_javax_security_cert_Certificate$vtype {
	_jc_type			type;
	_jc_javax_security_cert_Certificate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_cert_Certificate$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_cert_Certificate$refs {
    _jc_javax_security_cert_Certificate$sub_refs	javax_security_cert_Certificate;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_cert_Certificate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_cert_Certificate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_cert_Certificate$sub_nonrefs	javax_security_cert_Certificate;
};

// Object instance structure
struct _jc_javax_security_cert_Certificate$object {
	_jc_javax_security_cert_Certificate$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_cert_Certificate$vtype	*vtype;
	_jc_javax_security_cert_Certificate$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_cert_Certificate$vtype _jc_javax_security_cert_Certificate$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_cert_Certificate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_cert_Certificate$class_object;

#endif	/* _JC_javax_security_cert_Certificate_H_ */
